( cd opt/kde/share/doc/HTML/es/kivio ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kivio ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kugar ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kugar ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kword ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/koffice ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/koffice ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/koshell ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kspread ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kspread ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kchart ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kchart ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kpresenter ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/thesaurus ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/es/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/kformula ; ln -sf /opt/kde/share/doc/HTML/es/common common )
